@@ -221,7 +221,7 @@ sub get_header {
 			# content-length header we try if all in @v are the same
 			my %v = map { $_ => 1 } @v;
 			return $v[0] if keys(%v) == 1; # ok, only one
-			croak( "multiple values for $key" );
+			croak( "multiple values for $key in packet:\n".$self->as_string );
 		}
 		return $v[0];
 	} else {
@@ -640,7 +640,7 @@ sub as_parts {
 sub sdp_body {
 	my Net::SIP::Packet $self = shift;
 	my $ct = $self->get_header( 'content-type' );
-	return if $ct && $ct ne 'application/sdp';
+	return if $ct && lc($ct) ne 'application/sdp';
 	my $body = ($self->as_parts)[3] || return;
 	return Net::SIP::SDP->new( $body );
 }
